from simplelayout.cli import get_options
from simplelayout.generator.core import generate_matrix
from simplelayout.generator.utils import save_matrix, save_fig, make_dir


def main():
    options = get_options()
    unit_layout = generate_matrix(
        options.board_grid,
        options.unit_grid,
        options.unit_n,
        options.positions)
    make_dir(options.outdir)
    full_path = options.outdir+'/'+options.file_name
    save_matrix(unit_layout, full_path)
    save_fig(unit_layout, full_path)


if __name__ == "__main__":
    main()



"""
数据生成的主要逻辑
"""


import numpy as np


def generate_matrix(
    board_grid: int, unit_grid: int, unit_n: int, positions: list
) -> np.ndarray:
    """生成指定布局矩阵

    Args:
        board_grid (int): 布局板分辨率，代表矩形区域的边长像素数
        unit_grid (int): 矩形组件分辨率
        unit_n (int): 组件数
        positions (list): 每个元素代表每个组件的位置
    Returns:
        np.ndarray: 布局矩阵
    """
    unit_n += 0
    amount_in_length = int(board_grid/unit_grid)
    unit_layout = np.zeros(shape=(board_grid, board_grid))
    for position in positions:
        index_hang = position//amount_in_length
        index_lie = position % amount_in_length
        if index_lie:
            index_lie -= 1

        else:
            index_hang -= 1
            index_lie = amount_in_length-1

        for i in range(unit_grid):
            for j in range(unit_grid):
                unit_layout[index_hang*unit_grid+i, index_lie*unit_grid+j] = 1

    return unit_layout



import argparse
import sys


def get_options():
    parser = argparse.ArgumentParser(description='SimpleLAyout')
    parser.add_argument('--board_grid', type=int, default=100)
    parser.add_argument('--unit_grid', type=int, default=10)
    parser.add_argument('--unit_n', type=int, default=3)
    parser.add_argument('--positions', type=int,
                        nargs='*', default=[1, 15, 33])
    parser.add_argument('--outdir', '-o', type=str, default='dir1/dir2')
    parser.add_argument('--file_name', type=str, default='example')

    options = parser.parse_args()
    # 要求 board_grid 能整除 unit_grid
    if (options.board_grid % options.unit_grid) != 0:
        sys.exit()

    # positions数量与 unit_n 一致；
    # 位置为从1开始的整数，上限为 (board_grid/unit_grid)^2
    if len(options.positions) == options.unit_n:
        for pos in options.positions:
            if pos >= 1 and pos <= (options.board_grid/options.unit_grid)**2:
                continue
    else:
        sys.exit()
    return options



from setuptools import setup, find_packages


setup(
    name='simplelayout-FantasticRF',
    version='1.1.0',
    package_dir={'': 'src'},
    packages=find_packages(where='src'),
    install_requires=['numpy', 'matplotlib', 'scipy'],
    entry_points={'console_scripts': ['simplelayout = simplelayout:main'], }
)
